@@ -21,7 +21,7 @@ __author__ = u'Juho Vepsäläinen'
 __author_email__ = "bebraw@gmail.com"
 __maintainer__ = u'Jessica Tegner'
 __url__ = 'https://github.com/JessicaTegner/pypandoc'
-__version__ = '1.11'
+__version__ = '1.13'
 __license__ = 'MIT'
 __description__ = "Thin wrapper for pandoc."
 __python_requires__ = ">=3.6"
@@ -43,6 +43,7 @@ __classifiers__ = [
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: 3.11',
+        'Programming Language :: Python :: 3.12',
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy'
     ]
@@ -116,7 +117,7 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
     :param list extra_args: extra arguments (list of strings) to be passed to pandoc
             (Default value = ())
 
-    :param str encoding: the encoding of the file or the input bytes (Default value = 'utf-8')
+    :param str encoding (deprecated): the encoding of the input bytes (Default value = 'utf-8')
 
     :param str outputfile: output will be written to outputfile or the converted content
             returned if None. The output filename can be specified as a string
@@ -137,16 +138,15 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
     :raises OSError: if pandoc is not found; make sure it has been installed and is available at
             path.
     """
-    # This if block effectively adds support for pathlib.Path objects
-    # and generators produced by pathlib.Path().glob().
-    if not isinstance(source_file, str):
-        try:
-            source_file = list(map(str, source_file))
-        except TypeError:
-            source_file = str(source_file)
+    # check if we have a working directory
+    # if we don't, we use the current working directory
+    if cworkdir is None:
+        cworkdir = os.getcwd()
+
+    # TODO: remove 'encoding' parameter and warning
+    if encoding != "utf-8":
+        logger.warning("The 'encoding' parameter will be removed in version 1.13. Just remove the parameter, because currently the method does not use it.")
 
-    if not _identify_path(source_file):
-        raise RuntimeError("source_file is not a valid path")
     if _is_network_path(source_file): # if the source_file is an url
         format = _identify_format_from_path(source_file, format)
         return _convert_input(source_file, format, 'path', to, extra_args=extra_args,
@@ -154,13 +154,45 @@ def convert_file(source_file:Union[list, str, Path, Generator], to:str, format:U
                           verify_format=verify_format, sandbox=sandbox,
                           cworkdir=cworkdir)
 
-    discovered_source_files = []
+    # convert the source file to a path object internally
     if isinstance(source_file, str):
-        discovered_source_files += glob.glob(source_file)
-    if isinstance(source_file, list): # a list of possibly file or file patterns. Expand all with glob
-        for filepath in source_file:
-            discovered_source_files.extend(glob.glob(filepath))
+        source_file = Path(source_file)
+    elif isinstance(source_file, list):
+        source_file = [Path(x) for x in source_file]
+    elif isinstance(source_file, Generator):
+        source_file = [Path(x) for x in source_file]
 
+
+    # we are basically interested to figure out if its an absolute path or not
+    # if it's not, we want to prefix the working directory
+    # if it's a list, we want to prefix the working directory to each item if it's not an absolute path
+    # if it is, just use the absolute path
+    if isinstance(source_file, list):
+        source_file = [x if x.is_absolute() else Path(cworkdir, x) for x in source_file]
+    elif isinstance(source_file, Generator):
+        source_file = (x if x.is_absolute() else Path(cworkdir, x) for x in source_file)
+    # check ifjust a single path was given
+    elif isinstance(source_file, Path):
+        source_file = source_file if source_file.is_absolute() else Path(cworkdir, source_file)
+
+
+    discovered_source_files = []
+    # if we have a list of files, we need to glob them
+    # if we have a single file, we need to glob it
+    # remember that we already converted the source_file to a path object
+    # so for glob.glob use both the dir and file name
+    if isinstance(source_file, list):
+        for single_source in source_file:
+            discovered_source_files.extend(glob.glob(str(single_source)))
+        if discovered_source_files == []:
+            discovered_source_files = source_file
+    else:
+        discovered_source_files.extend(glob.glob(str(source_file)))
+        if discovered_source_files == []:
+            discovered_source_files = [source_file]
+
+    if not _identify_path(discovered_source_files):
+        raise RuntimeError("source_file is not a valid path")
     format = _identify_format_from_path(discovered_source_files[0], format)
     if len(discovered_source_files) == 1:
         discovered_source_files = discovered_source_files[0]
@@ -303,8 +335,16 @@ def _validate_formats(format, to, outputfile):
     if base_to_format == "pdf":
         # pdf formats needs to actually have a to format of latex and a
         # filename with an ending pf .pdf
-        if outputfile[-4:] != ".pdf":
-            raise RuntimeError('PDF output needs an outputfile with ".pdf" as a fileending.')
+        if isinstance(outputfile, str):
+            if outputfile[-4:] != ".pdf":
+                raise RuntimeError(
+                    'PDF output needs an outputfile with ".pdf" as a fileending.'
+                )
+        elif isinstance(outputfile, Path):
+            if outputfile.suffix != ".pdf":
+                raise RuntimeError(
+                    'PDF output needs an outputfile with ".pdf" as a fileending.'
+                )
         # to is not allowed to contain pdf, but must point to latex
         # it's also not allowed to contain extensions according to the docs
         if to != base_to_format:
@@ -410,7 +450,8 @@ def _convert_input(source, format, input_type, to, extra_args=(),
         raise RuntimeError('Pandoc died with exitcode "%s" during conversion.' % (p.returncode))
 
     try:
-        stdout = stdout.decode('utf-8')
+        if not (to in ["odt", "docx", "epub", "epub3", "pdf"] and outputfile == "-"):
+            stdout = stdout.decode('utf-8')
     except UnicodeDecodeError:
         # this shouldn't happen: pandoc more or less guarantees that the output is utf-8!
         raise RuntimeError('Pandoc output was not utf-8.')
@@ -666,7 +707,10 @@ def _ensure_pandoc_path() -> None:
         search_paths = ["pandoc", included_pandoc]
         pf = "linux" if sys.platform.startswith("linux") else sys.platform
         try:
-            search_paths.append(os.path.join(DEFAULT_TARGET_FOLDER[pf], "pandoc"))
+            if pf == "win32":
+                search_paths.append(os.path.join(DEFAULT_TARGET_FOLDER[pf], "pandoc.exe"))
+            else:
+                search_paths.append(os.path.join(DEFAULT_TARGET_FOLDER[pf], "pandoc"))
         except:  # noqa
             # not one of the know platforms...
             pass
@@ -676,16 +720,19 @@ def _ensure_pandoc_path() -> None:
         # Also add the interpreter script path, as that's where pandoc could be
         # installed if it's an environment and the environment wasn't activated
         if pf == "win32":
-            search_paths.append(os.path.join(sys.exec_prefix, "Scripts", "pandoc"))
+            search_paths.append(os.path.join(sys.exec_prefix, "Scripts", "pandoc.exe"))
 
             # Since this only runs on Windows, use Windows slashes
             if os.getenv('ProgramFiles', None):
-                search_paths.append(os.path.expandvars("${ProgramFiles}\\Pandoc\\Pandoc"))
+                search_paths.append(os.path.expandvars("${ProgramFiles}\\Pandoc\\pandoc.exe"))
+                search_paths.append(os.path.expandvars("${ProgramFiles}\\Pandoc\\Pandoc.exe"))
             if os.getenv('ProgramFiles(x86)', None):
-                search_paths.append(os.path.expandvars("${ProgramFiles(x86)}\\Pandoc\\Pandoc"))
+                search_paths.append(os.path.expandvars("${ProgramFiles(x86)}\\Pandoc\\pandoc.exe"))
+                search_paths.append(os.path.expandvars("${ProgramFiles(x86)}\\Pandoc\\Pandoc.exe"))
 
         # bin can also be used on windows (conda at least has it in path), so
         # include it unconditionally
+        search_paths.append(os.path.join(sys.exec_prefix, "bin", "pandoc.exe"))
         search_paths.append(os.path.join(sys.exec_prefix, "bin", "pandoc"))
         # If a user added the complete path to pandoc to an env, use that as the
         # only way to get pandoc so that a user can overwrite even a higher
@@ -704,7 +751,7 @@ def _ensure_pandoc_path() -> None:
             except Exception:
                 # we can't use that path...
                 if os.path.exists(path):
-                    # path exist but is not useable -> not executable?
+                    # path exist but is not usable -> not executable?
                     log_msg = ("Found {}, but not using it because of an "
                                "error:".format(path))
                     logger.exception(log_msg)
